@@ -25,35 +25,35 @@ class LogWriter():
         self.create_logfile()
 
     def create_logfile(self):
-        with open(self.filepath, "x", encoding=self.encoding) as f:
+        with open(self.filepath, "x", encoding=self.encoding, errors='replace') as f:
             f.write("")
     
     def debug(self, string):
-        with open(self.filepath, "a", encoding=self.encoding) as f:
+        with open(self.filepath, "a", encoding=self.encoding, errors='replace') as f:
             f.write("DEBUG,%s,%s\n" % (get_datetime_now(), string))
         print("[DEBUG] - %s\n%s\n" % (get_datetime_now(), string))
         self.debug_num += 1
     
     def info(self, string):
-        with open(self.filepath, "a", encoding=self.encoding) as f:
+        with open(self.filepath, "a", encoding=self.encoding, errors='replace') as f:
             f.write("INFO,%s,%s\n" % (get_datetime_now(), string))
         print("[INFO] - %s\n%s\n" % (get_datetime_now(), string))
         self.info_num += 1
     
     def warn(self, string):
-        with open(self.filepath, "a", encoding=self.encoding) as f:
+        with open(self.filepath, "a", encoding=self.encoding, errors='replace') as f:
             f.write("WARN,%s,%s\n" % (get_datetime_now(), string))
         print("[WARN] - %s\n%s\n" % (get_datetime_now(), string))
         self.warn_num += 1
     
     def error(self, string):
-        with open(self.filepath, "a", encoding=self.encoding) as f:
+        with open(self.filepath, "a", encoding=self.encoding, errors='replace') as f:
             f.write("ERROR,%s,%s\n" % (get_datetime_now(), string))
         print("[ERROR] - %s\n%s\n" % (get_datetime_now(), string))
         self.error_num += 1
     
     def fatal(self, string):
-        with open(self.filepath, "a", encoding=self.encoding) as f:
+        with open(self.filepath, "a", encoding=self.encoding, errors='replace') as f:
             f.write("FATAL,%s,%s\n" % (get_datetime_now(), string))
         print("[FATAL] - %s\n%s\n" % (get_datetime_now(), string))
         self.fatal_num += 1
